# -*- coding: utf-8 -*-


class MagnetIndexError(Exception):
    """Raise when trying to access a non existing magnet"""

    pass
